@@ -2,7 +2,7 @@ use super::*;
 
 impl TableBuilder for MysqlQueryBuilder {
     fn prepare_column_def(&self, column_def: &ColumnDef, sql: &mut SqlWriter) {
-        column_def.name.prepare(sql, '`');
+        column_def.name.prepare(sql, self.quote());
 
         if let Some(column_type) = &column_def.types {
             write!(sql, " ").unwrap();
@@ -88,6 +88,8 @@ impl TableBuilder for MysqlQueryBuilder {
                 ColumnType::JsonBinary => "json".into(),
                 ColumnType::Uuid => "binary(16)".into(),
                 ColumnType::Custom(iden) => iden.to_string(),
+                ColumnType::Enum(_, variants) => format!("ENUM('{}')", variants.join("', '")),
+                ColumnType::Array(_) => unimplemented!("Array is not available in MySQL."),
             }
         )
         .unwrap()
@@ -113,7 +115,7 @@ impl TableBuilder for MysqlQueryBuilder {
         };
         write!(sql, "ALTER TABLE ").unwrap();
         if let Some(table) = &alter.table {
-            table.prepare(sql, '`');
+            table.prepare(sql, self.quote());
             write!(sql, " ").unwrap();
         }
         match alter_option {
@@ -127,13 +129,13 @@ impl TableBuilder for MysqlQueryBuilder {
             }
             TableAlterOption::RenameColumn(from_name, to_name) => {
                 write!(sql, "RENAME COLUMN ").unwrap();
-                from_name.prepare(sql, '`');
+                from_name.prepare(sql, self.quote());
                 write!(sql, " TO ").unwrap();
-                to_name.prepare(sql, '`');
+                to_name.prepare(sql, self.quote());
             }
             TableAlterOption::DropColumn(column_name) => {
                 write!(sql, "DROP COLUMN ").unwrap();
-                column_name.prepare(sql, '`');
+                column_name.prepare(sql, self.quote());
             }
         }
     }
@@ -141,11 +143,11 @@ impl TableBuilder for MysqlQueryBuilder {
     fn prepare_table_rename_statement(&self, rename: &TableRenameStatement, sql: &mut SqlWriter) {
         write!(sql, "RENAME TABLE ").unwrap();
         if let Some(from_name) = &rename.from_name {
-            from_name.prepare(sql, '`');
+            from_name.prepare(sql, self.quote());
         }
         write!(sql, " TO ").unwrap();
         if let Some(to_name) = &rename.to_name {
-            to_name.prepare(sql, '`');
+            to_name.prepare(sql, self.quote());
         }
     }
 }
