@@ -24,7 +24,7 @@ impl IndexBuilder for SqliteQueryBuilder {
 
         write!(sql, " ON ").unwrap();
         if let Some(table) = &create.table {
-            table.prepare(sql, '`');
+            table.prepare(sql, self.quote());
         }
 
         // self.prepare_index_type(&create.index_type, sql);
@@ -35,12 +35,13 @@ impl IndexBuilder for SqliteQueryBuilder {
     fn prepare_index_drop_statement(&self, drop: &IndexDropStatement, sql: &mut SqlWriter) {
         write!(sql, "DROP INDEX ").unwrap();
         if let Some(name) = &drop.index.name {
-            write!(sql, "`{}`", name).unwrap();
+            let quote = self.quote();
+            write!(sql, "{}{}{}", quote, name, quote).unwrap();
         }
 
         write!(sql, " ON ").unwrap();
         if let Some(table) = &drop.table {
-            table.prepare(sql, '`');
+            table.prepare(sql, self.quote());
         }
     }
 
