@@ -39,9 +39,15 @@ macro_rules! bind_params_sqlx_sqlite {
                     } else if value.is_date() {
                         query.bind(value.as_ref_date())
                     } else if value.is_time() {
-                        query.bind(value.as_ref_time().map(|t| t.format("%T.f").to_string()))
+                        query.bind(value.as_ref_time())
                     } else if value.is_date_time() {
                         query.bind(value.as_ref_date_time())
+                    } else if value.is_date_time_utc() {
+                        query.bind(value.as_naive_utc_in_string())
+                    } else if value.is_date_time_local() {
+                        query.bind(value.as_naive_utc_in_string())
+                    } else if value.is_date_time_with_time_zone() {
+                        query.bind(value.as_naive_utc_in_string())
                     } else if value.is_decimal() {
                         query.bind(value.decimal_to_f64())
                     } else if value.is_big_decimal() {
